==> rivet-3.1.11.tar.gz: Rivet-3.1.11/analyses/pluginPetra/CELLO_1989_I266414.cc <==
// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {


  /// @brief gamma gamma -> KKpi
  class CELLO_1989_I266414 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(CELLO_1989_I266414);


    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      // Initialise and register projections
      declare(FinalState(), "FS");
      // book histos
      if(inRange(sqrtS()/GeV,1.4,4.2)) {
       	book(_nKKPi,"TMP/nKKPi");
      }
      else
	throw Error("Invalid CMS energy for CELLO_1989_I266414");
    }


    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& fs = apply<FinalState>(event, "FS");
      // find the final-state particles
      map<long,int> nCount;
      int ntotal(0);
      for (const Particle& p : fs.particles()) {
	nCount[p.pid()] += 1;
	++ntotal;
      }
      if(ntotal!=3) vetoEvent;
      if(nCount[PID::K0S]==1 && ( (nCount[PID::PIPLUS ]==1 && nCount[PID::KMINUS]==1 ) ||
				  (nCount[PID::PIMINUS]==1 && nCount[PID::KPLUS]==1 )))
	_nKKPi->fill();
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      double fact = crossSection()/nanobarn/sumOfWeights();
      double sigma = _nKKPi->val()*fact;
      double error = _nKKPi->err()*fact;
      Scatter2D temphisto(refData(1, 1, 1));
      Scatter2DPtr mult;
      book(mult, 1, 1, 1);
      for (size_t b = 0; b < temphisto.numPoints(); b++) {
	const double x  = temphisto.point(b).x();
	pair<double,double> ex = temphisto.point(b).xErrs();
	pair<double,double> ex2 = ex;
	if(ex2.first ==0.) ex2. first=0.0001;
	if(ex2.second==0.) ex2.second=0.0001;
	if (inRange(sqrtS(), x-ex2.first, x+ex2.second)) {
	  mult->addPoint(x, sigma, ex, make_pair(error,error));
	}
	else {
	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
	}
      }
    }

    /// @}


    /// @name Histograms
    /// @{
    CounterPtr _nKKPi;
    /// @}


  };


  RIVET_DECLARE_PLUGIN(CELLO_1989_I266414);

}

==> rivet-4.1.0.tar.gz: Rivet-4.1.0/analyses/pluginPetra/CELLO_1989_I266414.cc <==
// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {


  /// @brief gamma gamma -> KKpi
  class CELLO_1989_I266414 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(CELLO_1989_I266414);


    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      // Initialise and register projections
      declare(FinalState(), "FS");
      // book histos
      if(inRange(sqrtS()/GeV,1.4,4.2)) {
       	book(_nKKPi,"TMP/nKKPi");
      }
      else {
        throw Error("Invalid CMS energy for CELLO_1989_I266414");
      }
    }


    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& fs = apply<FinalState>(event, "FS");
      // find the final-state particles
      map<long,int> nCount;
      int ntotal(0);
      for (const Particle& p : fs.particles()) {
        nCount[p.pid()] += 1;
        ++ntotal;
      }
      if (ntotal!=3) vetoEvent;
      if (nCount[PID::K0S]==1 &&
          ( (nCount[PID::PIPLUS ]==1 && nCount[PID::KMINUS]==1 ) ||
            (nCount[PID::PIMINUS]==1 && nCount[PID::KPLUS]==1 ))) {
        _nKKPi->fill();
      }
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      scale(_nKKPi, crossSection()/nanobarn/sumOfWeights());
      Estimate1DPtr mult;
      book(mult, 1, 1, 1);
      for (auto& b : mult->bins()) {
        if (inRange(sqrtS()/GeV, b.xMin(), b.xMax())) {
          b.set(_nKKPi->val(), _nKKPi->err());
        }
      }
    }

    /// @}


    /// @name Histograms
    /// @{
    CounterPtr _nKKPi;
    /// @}


  };


  RIVET_DECLARE_PLUGIN(CELLO_1989_I266414);

}
